@@ -1240,7 +1240,7 @@ end
     linsolve_tmp = @.. du + dtd[1] * dT
     k1 = _reshape(W \ -_vec(linsolve_tmp), axes(uprev))
     # constant number for type stability make sure this is greater than num_stages
-    ks = ntuple(Returns(k1), 10)
+    ks = ntuple(Returns(k1), 20)
     # Loop for stages
     for stage in 2:num_stages
         u = uprev
@@ -1268,11 +1268,26 @@ end
         ks = Base.setindex(ks, _reshape(W \ -_vec(linsolve_tmp), axes(uprev)), stage)
         integrator.stats.nsolve += 1
     end
-    #@show ks
-    u = u .+ ks[num_stages]
+    if (integrator.alg isa Rodas6P)
+      du = ks[16]
+      u = uprev
+      for i in 1:15
+         u = @.. u + A[16, i] * ks[i]
+      end
+      u = u .+ ks[16]
+    else
+      du = ks[num_stages]
+      u = u .+ ks[num_stages]
+    end
 
     if integrator.opts.adaptive
-        atmp = calculate_residuals(ks[num_stages], uprev, u, integrator.opts.abstol,
+        if (integrator.alg isa Rodas5Pe)
+            du = 0.2606326497975715 * ks[1] - 0.005158627295444251 * ks[2] +
+                 1.3038988631109731 * ks[3] + 1.235000722062074 * ks[4] +
+                -0.7931985603795049 * ks[5] - 1.005448461135913 * ks[6] -
+                0.18044626132120234 * ks[7] + 0.17051519239113755 * ks[8]
+        end
+        atmp = calculate_residuals(du, uprev, u, integrator.opts.abstol,
             integrator.opts.reltol, integrator.opts.internalnorm, t)
         integrator.EEst = integrator.opts.internalnorm(atmp, t)
     end
@@ -1381,8 +1396,17 @@ end
         @.. $(_vec(ks[stage])) = -linres.u
         integrator.stats.nsolve += 1
     end
-    du .= ks[end]
-    u .+= ks[end]
+    if (integrator.alg isa Rodas6P)
+      du .= ks[16]
+      u .= uprev
+      for i in 1:15
+          @.. u += A[16, i] * ks[i]
+      end
+      u .+= ks[16]
+    else
+      du .= ks[end]
+      u .+= ks[end]
+    end
 
     step_limiter!(u, integrator, p, t + dt)
 
@@ -1393,7 +1417,7 @@ end
                      -0.7931985603795049 * ks[5] - 1.005448461135913 * ks[6] -
                      0.18044626132120234 * ks[7] + 0.17051519239113755 * ks[8]
         end
-        calculate_residuals!(atmp, ks[end], uprev, u, integrator.opts.abstol,
+        calculate_residuals!(atmp, du, uprev, u, integrator.opts.abstol,
             integrator.opts.reltol, integrator.opts.internalnorm, t)
         integrator.EEst = integrator.opts.internalnorm(atmp, t)
     end
