@@ -373,6 +373,55 @@ function Rodas5PTableau(T, T2)
     RodasTableau{T, T2}(RODAS5PA, RODAS5PC, gamma, RODAS5Pc, RODAS5Pd, RODAS5PH)
 end
 
+const RODAS6PA = [0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 1.7111784962693573 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 3.338661438538325 1.7785154948506772 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 2.936071270275081 0.9182685464146361 0.3700626437020361 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 4.659498341685848 1.750740798902701 0.5870646872926452 0.8880273208834594 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 4.0197306615530755 2.839611966871549 -0.5985886977898102 0.08804800108767567 1.5622259206803966 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 1.988416726724047 -0.379547946940864 0.9004347186464728 1.4277449221484224 -0.7433508015345144 -0.042432590368607255 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 1.8376133238441654 1.9114959548124457 -0.6715227349230231 0.2358079620635186 3.6095202089874117 0.8151701113738031 0.9206065341545108 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ -0.766306772356088 3.209956697664864 -3.3123779344961592 -3.0203200762095332 4.800864725315542 1.1604579105760842 0.4424812765132964 0.3706918590956091 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 6.232416226700401 2.6089061288608786 -0.6004565639275875 -3.3845987889094653 0.42397260663019737 0.35421155529651493 0.30716464971632756 1.5008969261275715 0.5102657561692372 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 0.023392109748070492 1.4081998520657641 -0.7199787823918794 0.7361286083371824 2.4632772861278043 0.46923886035475726 0.1205787235019629 -0.8578747086506138 -0.2588726092696778 -0.4397748045492015 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 2.953951852943472 -0.5094757863221286 0.3109577019600045 -3.5298051247141733 -3.545755924579993 -0.33681829638738314 -0.5663219967973026 1.1332773651373889 0.15030559921640937 0.25755454716019555 0.29836356640198125 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 3.613614004197333 0.6635854700997046 0.021719370087612728 -1.4950066071478674 0.7257768429136315 -0.05542296424699332 0.6617050893162496 1.5916006835996634 0.004468857383033254 0.3492741589610665 -0.20270398239783438 0.6407744206145284 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 0.6650675322630164 3.8649437891996143 -3.5568168140908862 0.30445082364848014 6.687033712252074 1.7577448564663951 0.7252352806302017 0.8340620415656512 0.288756122559755 -0.014344518613253377 -0.9202387269679146 0.1235675186947092 0.5210532009614854 0.0 0.0 0.0 0.0 0.0 0.0
+ 0.6650675322630163 3.864943789199614 -3.5568168140908876 0.30445082364847914 6.687033712252074 1.7577448564663951 0.7252352806302018 0.834062041565651 0.2887561225597551 -0.014344518613253487 -0.9202387269679145 0.12356751869470915 0.5210532009614851 1.0 0.0 0.0 0.0 0.0 0.0
+ 0.6650675322630177 3.864943789199614 -3.5568168140908876 0.30445082364847964 6.687033712252074 1.7577448564663947 0.7252352806302018 0.8340620415656512 0.2887561225597553 -0.014344518613253388 -0.9202387269679146 0.12356751869470915 0.5210532009614847 0.9999999999999998 1.0 0.0 0.0 0.0 0.0
+ 19.50552823691581 19.347153108620457 8.914549824296701 19.841538938728135 -30.357562810836335 -5.8051482228142195 -20.70248562796752 -21.376641384544037 -8.3987892732033 -7.736419267379574 2.0685219772918724 -8.760228330317224 5.418493374208782 1.6147496952752922 -2.4936078709750045 -2.2780749437287913 0.0 0.0 0.0
+ 56.666079713903386 5.165818087889462 22.35860178936739 10.763846891315566 -12.19955923582867 -0.6557677952689249 6.699011373303813 8.198746354754231 1.677616608414471 3.1277285768268968 1.4179582645760416 -2.2744851263878836 -1.7540829181840385 -2.0011264405011304 -2.473136836317977 -1.8837562152980634 0.10307912091592847 0.0 0.0
+ 0.4516803503254423 -1.1534041395134922 -4.845280220499032 -23.586737710513358 1.6878417137075876 0.7868554635343545 3.0270371561482805 6.0990245036017745 2.600755391135945 1.3246029905944345 2.0716827798306645 1.0885240892776982 -2.406764303616696 -1.0934035335348031 -0.08817028752603433 0.1628623060793163 -0.0494871328758008 -0.053891050773493175 0.0]
+const RODAS6PC = [0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ -6.581455754882143 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ -17.99898897860265 -8.573983492685619 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ -9.381383431453385 -3.147640353879416 -1.3459246069197102 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ -2.6265331637613007 -4.114341661049238 2.3552716210903446 0.7916860595752533 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 13.234071865054425 -6.5531726714288245 10.73126008968739 7.881893740344428 -12.771533510641573 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 2.830906994202388 0.2604988641272497 1.2537810312593667 -3.3671244579321455 -10.786563365589606 -1.9308385166591397 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ -11.060311196714387 -1.3456656966931244 -0.7657970115506183 6.107723730659436 2.2037867523584938 -0.07238767937020778 -0.8050462039096485 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ -18.12844382677043 -8.753725825758918 2.21059342699439 11.608007179779365 -0.05812583279366939 -0.5568300956262869 0.22469855334210373 -3.2370311176417705 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ -27.976343920035056 -8.591555353546772 0.7281452536154736 17.638493457476986 -5.306189757628467 -3.0476569146401444 -5.904770682441327 -11.929084037829442 -5.050568446376497 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 16.354749252471326 1.4669223994142209 5.928484441955681 10.74513480723443 10.673355125609953 3.688805562318594 9.180717730517506 10.247712646451996 1.465303310058304 2.6508985881732774 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 6.914935441832399 5.38984958631352 5.862037438875566 5.348681436005972 -7.013382408252529 -1.0246660674824237 -2.9837100715597376 -5.836566084094612 -1.6109549842142277 -1.1760399923017764 1.9280128334739643 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 4.198711896534994 0.6181084056782703 0.8167077246607498 -11.236495255410707 -4.824409089261172 0.7728367826492113 1.3033341851336357 3.1220057171705977 1.917167519177393 0.740911936448596 2.3884839541537675 -1.0646261824518854 0.0 0.0 0.0 0.0 0.0 0.0 0.0
+ 8.439457273665866 -12.395217711948733 8.717809686910918 -22.620864451522902 -20.113605406532766 -4.689776805197894 1.6982447341017708 4.543406791431926 1.613366829028557 1.9707273458768597 5.732578765805261 1.7624664316708778 -5.245856774591262 0.0 0.0 0.0 0.0 0.0 0.0
+ 1.71450490512272 -13.840042084553074 6.437347401872298 -39.22048912909508 -25.603335547270504 -8.064795628637777 -0.0416146802576695 1.2346482358729156 2.7009872115209252 0.896525973043981 11.303609670096813 1.7547024586563815 -10.02276713006834 -6.93945857648056 0.0 0.0 0.0 0.0 0.0
+ 19.61213176916848 -14.311603723508286 12.96694128305561 -28.107332490598257 -27.192311861144052 -4.26577843330566 4.2210733410202135 10.487402162301366 0.8300940888935481 2.8025411207314455 8.878715452726594 1.4612348690788786 -9.853595041510669 -7.6808377648250294 -6.870056791600298 0.0 0.0 0.0 0.0
+ -371.4374434114548 -183.45541467767708 -245.2624549214238 -955.0201586246473 19.423673137681643 -0.9607917923114558 84.24290713671253 150.79467360315542 63.95986343894305 44.75849836276605 140.71019894715903 48.45923399488863 -146.47504553991118 -81.54609927566207 -25.07839993898753 3.829875020371404 0.0 0.0 0.0
+ -164.17333724090065 -123.20834760012879 41.95443520088893 -239.77049586199965 -114.21790985713952 -12.341946126859007 15.750890701780254 39.790586318490696 -15.10728752295998 -12.824535901748304 16.73312629333741 -11.045750202895642 -14.639022723428816 -4.819493713790297 0.12987727446051117 0.04274137296376776 1.204312390836273 0.0 0.0
+ 461.9368267656361 52.53840694165619 144.8183760448168 455.9093893534564 35.81740627464267 40.776479432911195 17.76376684531324 -7.606209560029927 -15.381956921574087 3.9317973949968428 -41.37771137941743 -44.920577584346 53.37495929469229 10.211466474320808 -15.84128439059478 -19.507483543094224 1.884309895179932 5.745356704710484 0.0]
+const RODAS6Pc = [0.0, 0.4449064090300329, 0.5391930604628539, 0.3920739557917205, 0.5393851240464334, 0.7496615946466092, 0.09171052879621677, 0.716762001806476, 0.9201684737037024, 0.7017495611178288, 0.5587152179138446, 0.10896187906446, 0.5073827520419607, 0.9999999999999999, 0.9999999999999999, 1.0000000000000002, 0.19999999999999996, 0.4999999999999998, 0.8]
+const RODAS6Pd = [0.26, -0.18490640903003291, -0.5445316852875675, -0.03230297796648507, -0.05985832397786847, 0.08292573124960323, 0.4158601113780379, -0.4887636036121086, -0.5305551731438798, 0.12166683722729399, -0.14899579330238244, 0.20995126195089908, -0.06287825975966793, -1.1102230246251565e-16, 1.1102230246251565e-16, 2.220446049250313e-16, 8.520155173756681, -7.34858003171262, 1.5593201340906078]
+const RODAS6PH = [17.587737160518465 -4.506717064391614 3.246011776864481 -5.070180845870549 -6.923968603369673 -1.6592466655000042 0.8383525386642399 1.2720777724693832 2.2171542815286456 1.2791183755209752 3.3596716472022443 -0.5508890465808383 -2.0565074886981494 -2.6056952102687827 -2.100871100634552 -1.8776167550373888 -0.022326222735958842 0.25936621048769365 -0.12973178185863266
+   -27.32817833553187 2.3528275077734033 7.155223685651038 10.820120934865187 -25.034320788396975 -8.268316122429903 -11.20195859714455 -5.95292555000712 -4.350123484395559 -3.4923279797567224 -7.522667509591013 6.313357154108988 3.434436480929646 4.500204746140061 3.6478467450775045 2.888705712728512 -0.031277730738519756 -1.0511708104283997 0.7378677397843861
+   48.135250596372614 1.6152029264444003 8.745836243957392 11.94240783069938 21.81240388443989 13.3043522805227 15.272804908450944 7.036607939296541 -2.212585956007379 3.686601637356048 8.623872556251557 -9.029595886738495 -6.643976834766214 -6.745850399987328 -7.810160738277424 -3.8140189856964035 0.04030442810903404 1.0072680387990685 -1.0126127084529764
+   -12.232391324631207 1.7643387246585114 -0.8009754670601623 -2.893944757628759 -7.972815842366974 1.309554861689306 -4.604493120665954 1.8134270309595735 -3.751773417632513 -0.5811994801517248 -2.741530578462468 0.300651942632877 2.0061263661214994 1.8521005591286555 -0.2324954254701126 0.6873479719072509 0.12936879836252782 -0.17980608456604885 0.32290862251165836]  
+function Rodas6PTableau(T, T2)
+    gamma = 0.26
+    RodasTableau{T, T2}(RODAS6PA, RODAS6PC, gamma, RODAS6Pc, RODAS6Pd, RODAS6PH)
+end
+
 @RosenbrockW6S4OS(:tableau)
 
 #=
